@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{ Astro::Coord::ECI::TLE };
 
-our $VERSION = '0.106_01';
+our $VERSION = '0.106_02';
 
 use Astro::Coord::ECI::Utils 0.091 qw{:all};
 use Carp;
@@ -1681,7 +1681,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Sun Sep 16 16:52:30 2018 GMT
+# on Thu Sep 20 22:45:34 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1692,7 +1692,7 @@ __PACKAGE__->status( add => 24796, iridium => '-', 'Iridium 4', 'Tumbling' );
 __PACKAGE__->status( add => 24836, iridium => '-', 'Iridium 914', 'Tumbling' );
 __PACKAGE__->status( add => 24837, iridium => 'D', 'Iridium 12', 'Decayed 2018-09-02' );
 __PACKAGE__->status( add => 24838, iridium => 'D', 'Iridium 9', 'Decayed 2003-03-11' );
-__PACKAGE__->status( add => 24839, iridium => 'S', 'Iridium 10', '' );
+__PACKAGE__->status( add => 24839, iridium => '-', 'Iridium 10', 'Tumbling' );
 __PACKAGE__->status( add => 24840, iridium => 'D', 'Iridium 13', 'Decayed 2018-04-29' );
 __PACKAGE__->status( add => 24841, iridium => '-', 'Iridium 16', 'Tumbling' );
 __PACKAGE__->status( add => 24842, iridium => '-', 'Iridium 911', 'Tumbling' );
@@ -1736,7 +1736,7 @@ __PACKAGE__->status( add => 25169, iridium => '+', 'Iridium 52', '' );
 __PACKAGE__->status( add => 25170, iridium => '-', 'Iridium 56', 'Tumbling' );
 __PACKAGE__->status( add => 25171, iridium => '+', 'Iridium 54', '' );
 __PACKAGE__->status( add => 25172, iridium => '-', 'Iridium 50', 'Tumbling' );
-__PACKAGE__->status( add => 25173, iridium => '+', 'Iridium 53', '' );
+__PACKAGE__->status( add => 25173, iridium => '-', 'Iridium 53', 'Tumbling' );
 __PACKAGE__->status( add => 25262, iridium => '-', 'Iridium 51', 'Tumbling' );
 __PACKAGE__->status( add => 25263, iridium => 'S', 'Iridium 61', '' );
 __PACKAGE__->status( add => 25272, iridium => 'S', 'Iridium 55', '' );
@@ -1753,7 +1753,7 @@ __PACKAGE__->status( add => 25290, iridium => 'D', 'Iridium 67', 'Decayed 2018-0
 __PACKAGE__->status( add => 25291, iridium => 'D', 'Iridium 68', 'Decayed 2018-06-06' );
 __PACKAGE__->status( add => 25319, iridium => '-', 'Iridium 69', 'Tumbling' );
 __PACKAGE__->status( add => 25320, iridium => '-', 'Iridium 71', 'Tumbling' );
-__PACKAGE__->status( add => 25342, iridium => '+', 'Iridium 70', '' );
+__PACKAGE__->status( add => 25342, iridium => 'S', 'Iridium 70', '' );
 __PACKAGE__->status( add => 25343, iridium => 'D', 'Iridium 72', 'Decayed 2018-05-14' );
 __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
@@ -1783,9 +1783,9 @@ __PACKAGE__->status( add => 27450, iridium => 'S', 'Iridium 97', '' );
 __PACKAGE__->status( add => 27451, iridium => 'D', 'Iridium 98', 'Decayed 2018-08-24' );
 
 # Summary:
-# Operational [+]: 12
+# Operational [+]: 10
 #       Spare [S]: 13
-#    Tumbling [-]: 37
+#    Tumbling [-]: 39
 #     Decayed [D]: 35
 
 1;
